# Table of Contents

- [business-capabilities-in-reference-catalog](<./business-capabilities-in-reference-catalog.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Business Capabilities in the Reference Catalog](<./Business-Capabilities-in-the-Reference-Catalog.md>)
  - [Overview](<./Business-Capabilities-in-the-Reference-Catalog/Overview.md>)
  - [Benefits](<./Business-Capabilities-in-the-Reference-Catalog/Benefits.md>)
  - [Permissions](<./Business-Capabilities-in-the-Reference-Catalog/Permissions.md>)
  - [Import Business Capabilities from the Reference Catalog](<./Business-Capabilities-in-the-Reference-Catalog/Import-Business-Capabilities-from-the-Reference-Catalog.md>)
  - [Imported Fields](<./Business-Capabilities-in-the-Reference-Catalog/Imported-Fields.md>)
  - [Link Existing Business Capabilities to Catalog Items](<./Business-Capabilities-in-the-Reference-Catalog/Link-Existing-Business-Capabilities-to-Catalog-Items.md>)
  - [Bulk Linking Business Capability Fact Sheets](<./Business-Capabilities-in-the-Reference-Catalog/Bulk-Linking-Business-Capability-Fact-Sheets.md>)
  - [Linking a Business Capability Fact Sheet from the Fact Sheet Page](<./Business-Capabilities-in-the-Reference-Catalog/Linking-a-Business-Capability-Fact-Sheet-from-the-Fact-Sheet-Page.md>)
  - [Changing or Unlinking Linked Items](<./Business-Capabilities-in-the-Reference-Catalog/Changing-or-Unlinking-Linked-Items.md>)
  - [Updates to the SAP Reference Architecture](<./Business-Capabilities-in-the-Reference-Catalog/Updates-to-the-SAP-Reference-Architecture.md>)
  - [Updating Linked Items to the Latest Version in Bulk](<./Business-Capabilities-in-the-Reference-Catalog/Updating-Linked-Items-to-the-Latest-Version-in-Bulk.md>)
  - [Updating the Linked Item to the Latest Version for a Single Fact Sheet](<./Business-Capabilities-in-the-Reference-Catalog/Updating-the-Linked-Item-to-the-Latest-Version-for-a-Single-Fact-Sheet.md>)
  - [Suggested SAP Solutions](<./Business-Capabilities-in-the-Reference-Catalog/Suggested-SAP-Solutions.md>)
  - [Deactivating the Suggested SAP Solutions Feature](<./Business-Capabilities-in-the-Reference-Catalog/Deactivating-the-Suggested-SAP-Solutions-Feature.md>)
